@@ -36,13 +36,9 @@ void VolumeMeterWidget::paintEvent(QPaintEvent *event){
     painter.setWindow(-150, -340, 300, 100);
 
     draw(& painter);
-
 }
 
 void VolumeMeterWidget::draw(QPainter *painter){
-    painter->setBackgroundMode(Qt::OpaqueMode);
-    painter->setBackground(QBrush(Qt::white));
-
     QRectF background(-150, -340, 300, 100);
     painter->drawRect(background);
     painter->fillRect(background, QBrush(Qt::white));
@@ -53,12 +49,8 @@ void VolumeMeterWidget::draw(QPainter *painter){
     QPen thickPen(Qt::black);
     thickPen.setWidth(4);
 
-    painter->setPen(thinPen);
-    painter->drawArc(-160, -295, 320, 150, 35*16, 110*16);
-
     painter->drawText(-20, -270, 40, 20, Qt::AlignCenter, "dB");
 
-    painter->setPen(thickPen);
     painter->rotate(-25);
     for(int i = 0; i < 23; i++){
         if(i % 4 == 0){
@@ -73,9 +65,13 @@ void VolumeMeterWidget::draw(QPainter *painter){
             if(i >= 16){
                 thinPen.setColor(Qt::red);
             }
-
             painter->setPen(thinPen);
-            painter->drawLine(0, -297, 0, -305);
+
+            if(i % 2 == 0){
+                painter->drawLine(0, -296, 0, -308);
+            }else{
+                painter->drawLine(0, -296, 0, -303);
+            }
         }
 
         painter->rotate(50./110.*5.);
@@ -85,10 +81,10 @@ void VolumeMeterWidget::draw(QPainter *painter){
     painter->rotate(-25);
     thinPen.setColor(Qt::black);
     painter->setPen(thinPen);
-    painter->drawArc(-160, -295, 320, 150, 40*16, 100*16);
+    painter->drawArc(-160, -295, 320, 150, 35*16, 110*16);
 
     painter->rotate(-25);
-    painter->rotate(50./110.*currentValue);
+    painter->rotate(50./110. * currentValue);
     thinPen.setColor(Qt::red);
     painter->setPen(thinPen);
     painter->drawLine(0, 0, 0, -325);
